#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>

#include "version.h"

int debug = 0;
int foreground = 0;
int long_interval = 60;
int short_interval = 1;

void usage(char **argv)
{
	fprintf(stderr, "watchdogd version %s\n", WATCHDOGD_VERSION);
	fprintf(stderr, "Usage: %s [ -d ] [ -f ] [ -l long interval ] [ -s short interval ]\n", argv[0]);
	fprintf(stderr, "Options:\n");
	fprintf(stderr, "  -d	--debug				Show debugging info\n");
	fprintf(stderr, "  -f	--foreground			Stay in foreground\n");
	fprintf(stderr, "  -l	--long_interval			Long sleep interval in seconds\n");
	fprintf(stderr, "  -s	--short_interval		Short sleep interval in seconds\n");
}

int options(int argc, char **argv)
{
	char *buf;
	int a, index;

	struct option options[] = {
		{"debug", no_argument, &debug, 1},
		{"foreground", no_argument, &foreground, 1},
		{"long_interval", required_argument, 0, 'l'},
		{"short_interval", required_argument, 0, 's'},
		{0, 0, 0, 0}
	};

	while ((a = getopt_long(argc, argv, "dfl:s:", options, &index)) != -1) {
		switch (a) {
		case 0:
			if (options[index].flag != 0)
				break;
		case 'd':
			debug = 1;
			break;
		case 'f':
			foreground = 1;
			break;
		case 'l':
			long_interval = strtol(optarg, &buf, 10);
			break;
		case 's':
			short_interval = strtol(optarg, &buf, 10);
			break;
		default:
			usage(argv);
			return -1;
			break;
		}
	}

	if (debug) {
		printf("will ");
		printf(foreground ? "not" : " ");
		printf(" fork\n");
		printf("long interval: %d\n", long_interval);
		printf("short interval: %d\n", short_interval);
	}

	return 0;
}
