#include <stdio.h>
#include <fcntl.h>
#include <signal.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <linux/fd.h>
#include <linux/fdreg.h>

#include "options.h"

struct floppy_raw_cmd spin_cmd;

int spin_disk(void)
{
	int a, fd;

	fd = open("/dev/floppy/0", O_ACCMODE | O_NONBLOCK);
	if (fd < 0) {
		perror("open");
		goto out1;
	}

	a = ioctl(fd, FDRAWCMD, &spin_cmd);
	if (a < 0) {
		perror("ioctl");
		goto out2;
	}

	sleep(1);

	a = ioctl(fd, FDRAWCMD, &spin_cmd);
	if (a < 0) {
		perror("ioctl");
		goto out2;
	}

	close(fd);

	return 0;

out2:
	close(fd);

out1:
	return -1;
}

void reset_timer(int signum)
{
	int i;

	if (debug)
		printf("received SIGUSR1\n");

	for (i = 0; i < 10; i++) {
		spin_disk();
		sleep(1);
	}
}

int main(int argc, char **argv)
{
	int a;

	a = options(argc, argv);
	if (a < 0)
		exit(1);

	if (!foreground) {
		int pid;

		pid = fork();

		if (pid > 0)
			exit(0);
	}

	signal(SIGUSR1, reset_timer);

	spin_cmd.data = 0;
	spin_cmd.rate = 0;
	spin_cmd.track = 0;
	spin_cmd.length = 0;

	spin_cmd.cmd[0] = FD_SEEK;
	spin_cmd.cmd[1] = 0;
	spin_cmd.cmd[1] = 0;
	spin_cmd.cmd_count = 3;
	spin_cmd.flags = FD_RAW_NEED_SEEK | FD_RAW_INTR;

	while (1)
		if (spin_disk() == 0)
			sleep(long_interval);
		else
			sleep(short_interval);

	return 0;
}
